# Choosing a Technology for Your Integration
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/choosing-technology-for-your-integration#overview)
  * [Use Out-of-the-Box Integrations](https://help.sap.com/docs/leanix/ea/choosing-technology-for-your-integration#use-out-of-the-box-integrations)
  * [Integrate Using the GraphQL API, REST APIs, and Webhooks](https://help.sap.com/docs/leanix/ea/choosing-technology-for-your-integration#integrate-using-the-graphql-api,-rest-apis,-and-webhooks)
  * [Build a Custom Integration Using the Integration API](https://help.sap.com/docs/leanix/ea/choosing-technology-for-your-integration#build-a-custom-integration-using-the-integration-api)


Factors that you need to consider when choosing a technology for your integration.
